@@ -712,8 +712,13 @@ class Provider(PersonProvider):
         Polish: Powszechny Elektroniczny System Ewidencji Ludności.
 
         PESEL has 11 digits which identifies just one person.
-        pesel_date: if person was born in 1900-2000, december is 12. If person was born > 2000, we have to add 20 to
-        month, so december is 32.
+        pesel_date: if person was born in
+                1900-1999 - month field number is not modified
+                2000–2099 – month field number is increased by 20
+                2100–2199 – month + 40
+                2200–2299 – month + 60
+                1800–1899 – month + 80
+                outside range 1800-2299 function will raise ValueError
         pesel_sex: last digit identifies person's sex. Even for females, odd for males.
 
         https://en.wikipedia.org/wiki/PESEL
@@ -721,9 +726,22 @@ class Provider(PersonProvider):
         if date_of_birth is None:
             date_of_birth = self.generator.date_of_birth()
 
-        month = date_of_birth.month if date_of_birth.year < 2000 else date_of_birth.month + 20
-        pesel_date = f'{date_of_birth:%y}{month:02d}{date_of_birth:%d}'
+        if 1800 <= date_of_birth.year <= 1899:
+            month = date_of_birth.month + 80
+        elif 1900 <= date_of_birth.year <= 1999:
+            month = date_of_birth.month
+        elif 2000 <= date_of_birth.year <= 2099:
+            month = date_of_birth.month + 20
+        elif 2100 <= date_of_birth.year <= 2199:
+            month = date_of_birth.month + 40
+        elif 2200 <= date_of_birth.year <= 2299:
+            month = date_of_birth.month + 60
+        else:
+            raise ValueError("Date of birth is out of supported range 1800-2299")
 
+        year = date_of_birth.year % 100
+
+        pesel_date = f'{year:02d}{month:02d}{date_of_birth.day:02d}'
         pesel_core = ''.join(map(str, (self.random_digit() for _ in range(3))))
         pesel_sex = self.random_digit()
 
